@@ -19,7 +19,7 @@ public:
     explicit CheckGravatarPlugin(QObject *parent = nullptr, const QList<QVariant> & = QList<QVariant>());
     ~CheckGravatarPlugin() override;
 
-    PimCommon::GenericPluginInterface *createInterface(QObject *parent = nullptr) override;
+    [[nodiscard]] PimCommon::GenericPluginInterface *createInterface(QObject *parent = nullptr) override;
 
     [[nodiscard]] bool hasPopupMenuSupport() const override;
 };
