@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,8 +16,8 @@ public:
     ~ScamConfigureSettingsDialog() override;
 
 private:
-    void readConfig();
-    void writeConfig();
-    void slotAccepted();
+    LIBSCAMCONFIGURESETTINGS_NO_EXPORT void readConfig();
+    LIBSCAMCONFIGURESETTINGS_NO_EXPORT void writeConfig();
+    LIBSCAMCONFIGURESETTINGS_NO_EXPORT void slotAccepted();
     ScamConfigureSettingsWidget *const mScamConfigureSettingsWidget;
 };
